@@ -45,6 +45,7 @@
 
 #include <osmocom/ranap/ranap_common.h>
 
+#include <osmocom/hnbgw/hnb.h>
 #include <osmocom/hnbgw/hnbgw.h>
 #include <osmocom/hnbgw/hnbgw_cn.h>
 #include <osmocom/hnbgw/hnbgw_pfcp.h>
@@ -314,6 +315,7 @@ int main(int argc, char **argv)
 	osmo_stream_srv_link_set_addr(srv, g_hnbgw->config.iuh_local_ip);
 	osmo_stream_srv_link_set_port(srv, g_hnbgw->config.iuh_local_port);
 	osmo_stream_srv_link_set_accept_cb(srv, hnbgw_rua_accept_cb);
+	osmo_stream_srv_link_set_msgb_alloc_info(srv, IUH_MSGB_SIZE, 0);
 
 	if (osmo_stream_srv_link_open(srv) < 0) {
 		perror("Cannot open server");
@@ -344,8 +346,8 @@ int main(int argc, char **argv)
 #endif
 	}
 
-	hnbgw_cnpool_start(&g_hnbgw->sccp.cnpool_iucs);
-	hnbgw_cnpool_start(&g_hnbgw->sccp.cnpool_iups);
+	hnbgw_cnpool_start(g_hnbgw->sccp.cnpool_iucs);
+	hnbgw_cnpool_start(g_hnbgw->sccp.cnpool_iups);
 
 	if (hnbgw_cmdline_config.daemonize) {
 		rc = osmo_daemonize();
